@@ -32,6 +32,9 @@
 static char THIS_FILE[] = __FILE__;
 #endif
 
+#define TOOLBAR_DRAFT_FILENAME _T("\\skin\\toolbar_draft.bmp")
+#define NUMBER_OF_TOOLBAR_DRAFT_ICON (6)
+
 /////////////////////////////////////////////////////////////////////////////
 // CDraftFrame
 
@@ -613,12 +616,32 @@ BOOL CDraftFrame::CreateToolbar()
 	CImageList img;
 	HINSTANCE hInst = AfxFindResourceHandle((LPCTSTR)IDR_TEST, RT_BITMAP);
 	ASSERT(hInst != NULL);
-	img.Attach(ImageList_LoadImage(hInst, (LPCTSTR)IDR_DRAFTFRAME, WIDTH_ICON_DRAFT, 0, /*CLR_NONE*/RGB(255, 255, 255), IMAGE_BITMAP, LR_CREATEDIBSECTION));
+
+	int nIconWidth = WIDTH_ICON_DRAFT;
+	int nIconHeight = HEIGHT_ICON_DRAFT;
+	LPCTSTR lpBitmap = (LPCTSTR)IDR_DRAFTFRAME;
+	UINT uFlags = LR_CREATEDIBSECTION;
+
+	CString strToolbarFilePath = ((CPochyApp*)::AfxGetApp())->m_app_path + TOOLBAR_DRAFT_FILENAME;
+	HBITMAP hBitmap = (HBITMAP)::LoadImage(hInst, strToolbarFilePath, IMAGE_BITMAP, 0, 0, LR_LOADFROMFILE);
+	if (hBitmap != NULL)
+	{
+		BITMAP bitmap;
+		if (::GetObject(hBitmap, sizeof(bitmap), &bitmap) > 0)
+		{
+			nIconWidth = bitmap.bmWidth / NUMBER_OF_TOOLBAR_DRAFT_ICON;
+			nIconHeight = bitmap.bmHeight;
+			lpBitmap = strToolbarFilePath;
+			uFlags |= LR_LOADFROMFILE;
+		}
+		::DeleteObject(hBitmap);
+	}
+
+	img.Attach(ImageList_LoadImage(hInst, lpBitmap, nIconWidth, 0, /*CLR_NONE*/RGB(255, 255, 255), IMAGE_BITMAP, uFlags));
 	m_wndToolBar.GetToolBarCtrl().SetImageList(&img);
 	img.Detach();
 
-	m_wndToolBar.SetSizes(CSize(WIDTH_ICON_DRAFT+7, HEIGHT_ICON_DRAFT+6), CSize(WIDTH_ICON_DRAFT, HEIGHT_ICON_DRAFT));
-
+	m_wndToolBar.SetSizes(CSize(nIconWidth + 7, nIconHeight + 6), CSize(nIconWidth, nIconHeight));
 	m_wndToolBar.SetButtons(NULL, 6);
 
 	m_wndToolBar.SetButtonInfo(0, ID_SEND_MAIL, TBSTYLE_BUTTON, 0);
