@@ -23,6 +23,8 @@
 static char THIS_FILE[] = __FILE__;
 #endif
 
+#define TREEVIEW_FILENAME _T("\\skin\\treeview.bmp")
+
 /////////////////////////////////////////////////////////////////////////////
 // CFolderView
 
@@ -106,9 +108,22 @@ void CFolderView::OnInitialUpdate()
 	// icon̐ݒ
 	if(this->m_image.Create(17, 16, ILC_COLOR8|ILC_MASK, 0, 7)){
 		CBitmap bmp;
-		if(bmp.LoadBitmap(IDB_TREEVIEW)){
+
+		CString strTreeviewFilePath = ((CPochyApp*)::AfxGetApp())->m_app_path + TREEVIEW_FILENAME;
+		HBITMAP hBitmap = (HBITMAP)::LoadImage(NULL, strTreeviewFilePath, IMAGE_BITMAP, 0, 0, LR_LOADFROMFILE);
+		if (hBitmap != NULL)
+		{
+			CBitmap* pBitmap = CBitmap::FromHandle(hBitmap);
+			if (pBitmap != NULL)
+			{
+				this->m_image.Add(pBitmap, RGB(255,255,255));
+			}
+			::DeleteObject(hBitmap);
+		}
+		else if(bmp.LoadBitmap(IDB_TREEVIEW)){
 			this->m_image.Add(&bmp, RGB(255,255,255));
 		}
+
 		bmp.DeleteObject();
 	}
 	tc.SetImageList(&m_image, TVSIL_NORMAL);
@@ -139,8 +154,8 @@ void CFolderView::OnInitialUpdate()
 		app->GetProfileInt("FolderViewColor", "TxtColorB", DEF_TXT_COLOR_B));
 	tc.SetTextColor(m_colorEdit);
 
-	CMainFrame *mf = (CMainFrame*)this->GetParentFrame(); // łapp->m_pMainWnd2͎gȂ
-	CString def_account = app->GetProfileString("DefaultMailBox", "BoxName", "");
+	CMainFrame *mf = (CMainFrame*)this->GetParentFrame();
+	CString def_account = mf->m_pAcntV->GetCurrentAccountName();
 	if(!def_account.IsEmpty()){
 		ConstructTree(def_account);
 	}else{
