@@ -32,6 +32,11 @@
 static char THIS_FILE[] = __FILE__;
 #endif
 
+#define WM_USER_NOTIFYICON (WM_APP + 100)
+#define TOOLBAR_MAIN_FILENAME _T("\\skin\\toolbar_main.bmp")
+#define TASKTRAY_ICON_FILENAME _T("\\skin\\tasktray.ico")
+#define NUMBER_OF_TOOLBAR_MAIN_ICON (10)
+
 /////////////////////////////////////////////////////////////////////////////
 // CMainFrame
 
@@ -39,6 +44,7 @@ IMPLEMENT_DYNCREATE(CMainFrame, CFrameWnd)
 
 BEGIN_MESSAGE_MAP(CMainFrame, CFrameWnd)
 	//{{AFX_MSG_MAP(CMainFrame)
+	ON_MESSAGE(WM_USER_NOTIFYICON, OnNotifyIcon)
 	ON_WM_CREATE()
 	ON_COMMAND(ID_FETCH_MAIL, OnFetchmail)
 	ON_UPDATE_COMMAND_UI(ID_FETCH_MAIL, OnUpdateFetchmail)
@@ -74,7 +80,7 @@ BEGIN_MESSAGE_MAP(CMainFrame, CFrameWnd)
 	ON_COMMAND(ID_GPG_MAIN_KEY_MANAGEMENT, OnGpgKeyManagement)
 	ON_WM_CLOSE()
 	ON_WM_COPYDATA()
-	ON_WM_CHAR()
+	ON_WM_SYSCOMMAND()
 	//}}AFX_MSG_MAP
 	ON_COMMAND(WM_PROGCREATE, OnProgCreate)
 END_MESSAGE_MAP()
@@ -156,6 +162,20 @@ int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
 		SetTimer(1, minute*60000, NULL);
 	}
 
+	// ^XNgCACRݒ肷
+	CString strTaskTrayIconFilePath = app->m_app_path + TASKTRAY_ICON_FILENAME;
+	m_notifyIcon.Initialize(app->m_hInstance, GetSafeHwnd(), WM_USER_NOTIFYICON);
+	if (!m_notifyIcon.SetIcon(strTaskTrayIconFilePath))
+	{
+		m_notifyIcon.SetIcon(IDR_MAINFRAME);
+	}
+	m_notifyIcon.SetTip(AFX_IDS_APP_TITLE);
+	int nUseTaskTray = app->GetProfileInt(_T("TaskTray"), _T("UseTaskTray"), 0);
+	if (nUseTaskTray == 1)
+	{
+		m_notifyIcon.Add();
+	}
+
 	return 0;
 }
 
@@ -326,12 +346,14 @@ void CMainFrame::OnGpgDec()
 
 	CStringArray old_header;
 	m_pTextV->m_md.m_hi.GetAllUnDecoded(old_header);
+	m_pTextV->m_md.m_hi.RemoveFoldingWhiteSpace(&old_header);
 
 	if(m_pTextV->IsPgpMime()){ // pgp/mimȅꍇ
 		CMimeDecode md;
 		md.DoIt2(buf);
 		CStringArray new_header;
 		md.m_hi.GetAllUnDecoded(new_header);
+		md.m_hi.RemoveFoldingWhiteSpace(&new_header);
 
 		CString content_type;
 		CString content_transfer_encoding;
@@ -660,11 +682,32 @@ BOOL CMainFrame::CreateToolbar()
 	CImageList img;
 	HINSTANCE hInst = AfxFindResourceHandle((LPCTSTR)IDR_TEST, RT_BITMAP);
 	ASSERT(hInst != NULL);
-	img.Attach(ImageList_LoadImage(hInst, (LPCTSTR)IDR_MAINFRAME, WIDTH_ICON_MAIN, 0, /*CLR_NONE*/RGB(255, 255, 255), IMAGE_BITMAP, LR_CREATEDIBSECTION));
+
+	int nIconWidth = WIDTH_ICON_MAIN;
+	int nIconHeight = HEIGHT_ICON_MAIN;
+	LPCTSTR lpBitmap = (LPCTSTR)IDR_MAINFRAME;
+	UINT uFlags = LR_CREATEDIBSECTION;
+
+	CString strToolbarFilePath = ((CPochyApp*)::AfxGetApp())->m_app_path + TOOLBAR_MAIN_FILENAME;
+	HBITMAP hBitmap = (HBITMAP)::LoadImage(hInst, strToolbarFilePath, IMAGE_BITMAP, 0, 0, LR_LOADFROMFILE);
+	if (hBitmap != NULL)
+	{
+		BITMAP bitmap;
+		if (::GetObject(hBitmap, sizeof(bitmap), &bitmap) > 0)
+		{
+			nIconWidth = bitmap.bmWidth / NUMBER_OF_TOOLBAR_MAIN_ICON;
+			nIconHeight = bitmap.bmHeight;
+			lpBitmap = strToolbarFilePath;
+			uFlags |= LR_LOADFROMFILE;
+		}
+		::DeleteObject(hBitmap);
+	}
+
+	img.Attach(ImageList_LoadImage(hInst, lpBitmap, nIconWidth, 0, /*CLR_NONE*/RGB(255, 255, 255), IMAGE_BITMAP, uFlags));
 	m_wndToolBar.GetToolBarCtrl().SetImageList(&img);
 	img.Detach();
 
-	m_wndToolBar.SetSizes(CSize(WIDTH_ICON_MAIN+7, HEIGHT_ICON_MAIN+6), CSize(WIDTH_ICON_MAIN, HEIGHT_ICON_MAIN));
+	m_wndToolBar.SetSizes(CSize(nIconWidth + 7, nIconHeight + 6), CSize(nIconWidth, nIconHeight));
 	m_wndToolBar.SetButtons(NULL, 9);
 
 	m_wndToolBar.SetButtonInfo( 0, ID_DRAFT, TBSTYLE_BUTTON, 0);
@@ -966,7 +1009,19 @@ void CMainFrame::GetStatusBarProgress(int &current, int &upper)
 void CMainFrame::OnSettingGeneral() 
 {
 	CSettingGeneralDlg sd;
-	sd.DoModal();
+	if (sd.DoModal() == IDOK)
+	{
+		// ^XNgCACR̐ݒ𔽉f
+		int nUseTaskTray = AfxGetApp()->GetProfileInt(_T("TaskTray"), _T("UseTaskTray"), 0);
+		if (nUseTaskTray == 1)
+		{
+			m_notifyIcon.Add();
+		}
+		else
+		{
+			m_notifyIcon.Delete();
+		}
+	}
 }
 
 void CMainFrame::OnSettingAccount() 
@@ -1189,9 +1244,86 @@ BOOL CMainFrame::OnCopyData(CWnd* pWnd, COPYDATASTRUCT* pCopyDataStruct)
 	return CFrameWnd::OnCopyData(pWnd, pCopyDataStruct);
 }
 
-void CMainFrame::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags) 
+LRESULT CMainFrame::OnNotifyIcon(WPARAM wParam, LPARAM lParam)
 {
-	AfxMessageBox("this");
-	this->Char(nChar);
-	CFrameWnd::OnChar(nChar, nRepCnt, nFlags);
+	if (wParam == m_notifyIcon.GetID())
+	{
+		switch (lParam)
+		{
+		case WM_RBUTTONDOWN:
+			{
+				GetLastActivePopup()->SetForegroundWindow();
+				POINT point;
+				if (::GetCursorPos(&point) != 0)
+				{
+					CMenu* pSystemMenu = GetSystemMenu(FALSE);
+					if (pSystemMenu != NULL)
+					{
+//						SetFocus();
+						pSystemMenu->DeleteMenu(SC_MOVE, MF_BYCOMMAND);
+						pSystemMenu->DeleteMenu(SC_SIZE, MF_BYCOMMAND);
+						pSystemMenu->DeleteMenu(SC_MINIMIZE, MF_BYCOMMAND);
+						pSystemMenu->DeleteMenu(SC_MAXIMIZE, MF_BYCOMMAND);
+						if (!IsIconic())
+						{
+							pSystemMenu->DeleteMenu(SC_RESTORE, MF_BYCOMMAND);
+							pSystemMenu->DeleteMenu(0, MF_BYPOSITION);
+						}
+						UINT uItem = pSystemMenu->TrackPopupMenu(
+							TPM_RIGHTALIGN | TPM_LEFTBUTTON | TPM_RIGHTBUTTON | TPM_RETURNCMD,
+							point.x, point.y, this, NULL);
+						PostMessage(WM_SYSCOMMAND, uItem, NULL);
+						GetSystemMenu(TRUE);
+					}
+				}
+			}
+			break;
+
+		case WM_LBUTTONDOWN:
+			{
+				if (IsIconic())
+				{
+					ShowWindow(SW_RESTORE);
+				}
+				GetLastActivePopup()->SetForegroundWindow();
+			}
+			break;
+
+		default:
+			break;
+		}
+	}
+
+	return 0;
+}
+
+LRESULT CMainFrame::WindowProc(UINT message, WPARAM wParam, LPARAM lParam) 
+{
+	if (message == m_notifyIcon.m_uTaskbarCreated)
+	{
+		m_notifyIcon.Add();
+	}
+	
+	return CFrameWnd::WindowProc(message, wParam, lParam);
+}
+
+void CMainFrame::OnSysCommand(UINT nID, LPARAM lParam) 
+{	
+	CFrameWnd::OnSysCommand(nID, lParam);
+
+	switch (nID)
+	{
+	case SC_MINIMIZE:
+		{
+			int nUseTaskTray = AfxGetApp()->GetProfileInt(_T("TaskTray"), _T("UseTaskTray"), 0);
+			int nTaskTrayOnly = AfxGetApp()->GetProfileInt(_T("TaskTray"), _T("TaskTrayOnly"), 0);
+			if (nUseTaskTray == 1 && nTaskTrayOnly == 1)
+			{
+				ShowWindow(SW_HIDE);
+			}
+		}
+		break;
+	default:
+		break;
+	}
 }
