@@ -43,6 +43,7 @@ void CMimeEncode::Initialize()
 	m_data.m_cc.Empty();
 	m_data.m_from.Empty();
 	m_data.m_in_reply_to.Empty();
+	m_data.m_references.Empty();
 	m_data.m_reply_to.Empty();
 	m_data.m_message_id.Empty();
 	m_data.m_subject.Empty();
@@ -203,10 +204,10 @@ CString CMimeEncode::GetMail(int for_what)
 			i++;
 		}
 		if(m_mime_mode == ME_MODE_NONE){
-			header += "Content-Type: Multipart/Mixed; boundary="+boundary+"\r\n";
+			header += "Content-Type: Multipart/Mixed;\r\n\tboundary=\""+boundary+"\"\r\n";
 			header += "Content-Transfer-Encoding: 7bit\r\n";
 		}else if(m_mime_mode == ME_MODE_PGP){
-			header += "Content-Type: Multipart/Encrypted; boundary="+boundary+"; protocol=application/pgp-encrypted\r\n";
+			header += "Content-Type: Multipart/Encrypted; protocol=application/pgp-encrypted;\r\n\tboundary=\""+boundary+"\"\r\n";
 			header += "Content-Transfer-Encoding: 7bit\r\n";
 		}else if(m_mime_mode == ME_MODE_RFC822){}
 		CCodeConvert cc(header);
