@@ -36,6 +36,9 @@ void CSettingAccountDlg::DoDataExchange(CDataExchange* pDX)
 {
 	CDialog::DoDataExchange(pDX);
 	//{{AFX_DATA_MAP(CSettingAccountDlg)
+	DDX_Control(pDX, IDC_SETTING_CHECK_SMTP_AUTH, m_smtp_auth);
+	DDX_Control(pDX, IDC_SETTING_SMTP_AUTH_PASS, m_smtp_auth_pass);
+	DDX_Control(pDX, IDC_SETTING_SMTP_AUTH_ID, m_smtp_auth_id);
 	DDX_Control(pDX, IDC_SETTING_DEF_ADDRESS_EDIT, m_def_address_edit);
 	DDX_Control(pDX, IDC_SETTING_DEF_ADDRESS, m_def_address);
 	DDX_Control(pDX, IDC_SETTING_CHECK_APOP, m_apop);
@@ -58,6 +61,7 @@ void CSettingAccountDlg::DoDataExchange(CDataExchange* pDX)
 BEGIN_MESSAGE_MAP(CSettingAccountDlg, CDialog)
 	//{{AFX_MSG_MAP(CSettingAccountDlg)
 	ON_CBN_SELCHANGE(IDC_SETTING_DEF_ADDRESS, OnSelchangeAutoAddress)
+	ON_BN_CLICKED(IDC_SETTING_CHECK_SMTP_AUTH, OnCheckSmtpAuth)
 	//}}AFX_MSG_MAP
 END_MESSAGE_MAP()
 
@@ -117,6 +121,24 @@ BOOL CSettingAccountDlg::OnInitDialog()
 
 	m_apop.SetCheck(GetPrivateProfileInt("pop", "apop", 0, path));
 
+	CString smtp_auth_id;
+	CString smtp_auth_pass;
+	m_smtp_auth.SetCheck(GetPrivateProfileInt("smtp", "auth", 0, path));
+	if(m_smtp_auth.GetCheck()){
+		m_smtp_auth_id.SetReadOnly(FALSE);
+		GetPrivateProfileString("smtp", "auth_id", "", smtp_auth_id.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+		smtp_auth_id.ReleaseBuffer();
+		m_smtp_auth_id.SetWindowText(smtp_auth_id);
+
+		m_smtp_auth_pass.SetReadOnly(FALSE);
+		GetPrivateProfileString("smtp", "auth_pass", "", smtp_auth_pass.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+		smtp_auth_pass.ReleaseBuffer();
+		m_smtp_auth_pass.SetWindowText(smtp_auth_pass);
+	}else{
+		m_smtp_auth_id.SetReadOnly();
+		m_smtp_auth_pass.SetReadOnly();
+	}
+
 	// default address
 	m_def_address.AddString("Cc");
 	m_def_address.AddString("Bcc");
@@ -205,6 +227,12 @@ void CSettingAccountDlg::OnOK()
 	itoa(m_apop.GetCheck(), check.GetBuffer(BUF_LENGTH), BUF_LENGTH);
 	check.ReleaseBuffer();
 	WritePrivateProfileString("pop", "apop", check, path);
+	// check smtp auth
+	itoa(m_smtp_auth.GetCheck(), check.GetBuffer(BUF_LENGTH), BUF_LENGTH);
+	check.ReleaseBuffer();
+	WritePrivateProfileString("smtp", "auth", check, path);
+	m_smtp_auth_id.GetWindowText(stmp); WritePrivateProfileString("smtp", "auth_id", stmp, path);
+	m_smtp_auth_pass.GetWindowText(stmp); WritePrivateProfileString("smtp", "auth_pass", stmp, path);
 
 	// save def address
 	int sel = m_def_address.GetCurSel();
@@ -229,3 +257,14 @@ void CSettingAccountDlg::OnSelchangeAutoAddress()
 	this->m_current_def_address = sel;
 
 }
+
+void CSettingAccountDlg::OnCheckSmtpAuth() 
+{
+	if(m_smtp_auth.GetCheck()){
+		m_smtp_auth_id.SetReadOnly(FALSE);
+		m_smtp_auth_pass.SetReadOnly(FALSE);
+	}else{
+		m_smtp_auth_id.SetReadOnly();
+		m_smtp_auth_pass.SetReadOnly();
+	}
+}
