@@ -174,10 +174,19 @@ void CSettingGeneralDlg::OnOK()
 	m_other_dlg.m_def_account.GetWindowText(buf);
 	app->WriteProfileString("DefaultMailBox", "boxname", buf);
 	// M̊ԊuݒXV
+/*	CString minute;
+	m_other_dlg.m_autofetch_minute.GetWindowText(minute);
+	if(minute.SpanExcluding("0123456789").IsEmpty()){
+		app->WriteProfileInt("AutoFetch", "minute", atoi(minute));
+	}*/
 	CString minute;
 	m_other_dlg.m_autofetch_minute.GetWindowText(minute);
 	if(minute.SpanExcluding("0123456789").IsEmpty()){
 		app->WriteProfileInt("AutoFetch", "minute", atoi(minute));
+		mf->KillTimer(1);
+		if(atoi(minute) >= 1){
+			mf->SetTimer(1, atoi(minute)*60000, NULL);
+		}
 	}
 
 	// font̕ύX
@@ -190,5 +199,11 @@ void CSettingGeneralDlg::OnOK()
 	}
 	app->WriteProfileBinary("EditViewFont", "LogFont", (LPBYTE)&m_appearance_dlg.m_ev_lf, sizeof(LOGFONT));
 
+	// ^XNgCACRݒ̕ۑ
+	int nUseTaskTray = m_other_dlg.m_checkUseTaskTray.GetCheck();
+	app->WriteProfileInt(_T("TaskTray"), _T("UseTaskTray"), nUseTaskTray);
+	int nTaskTrayOnly = m_other_dlg.m_checkTaskTrayOnly.GetCheck();
+	app->WriteProfileInt(_T("TaskTray"), _T("TaskTrayOnly"), nTaskTrayOnly);
+
 	CDialog::OnOK();
 }
