@@ -19,6 +19,8 @@ public:
 // _CAO f[^
 	//{{AFX_DATA(CSettingGeneralOtherDlg)
 	enum { IDD = IDD_SETTING_GENERAL_OTHER };
+	CButton	m_checkTaskTrayOnly;
+	CButton	m_checkUseTaskTray;
 	CEdit	m_autofetch_minute;
 	CComboBox	m_def_account;
 	CEdit	m_editor_path;
@@ -40,6 +42,7 @@ protected:
 	afx_msg void OnEditorRef();
 	virtual BOOL OnInitDialog();
 	virtual void OnOK();
+	afx_msg void OnSettingGeneralUseTasktray();
 	//}}AFX_MSG
 	DECLARE_MESSAGE_MAP()
 };
