@@ -373,9 +373,9 @@ void CSummaryView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags)
 		}
 		break;
 	case 'x':
-		for(i=0; i < this->m_array_list.GetSize(); i++){
+		for(i=this->m_array_list.GetSize()-1; i >= 0; i--){
 			if(this->m_array_list.GetAt(i).m_str6.Find("D") != -1){
-				ia.Add(i);
+				ia.Add(this->m_stack_num-i-1);
 			}
 		}
 		if(fv->GetSelectedItemKind() != FV_TRASH){
@@ -383,14 +383,16 @@ void CSummaryView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags)
 		}else{
 			CString null;
 			null.Empty();
-			this->MoveMail(ia, null, SMRY_COLUMN_FROM);
+			this->DeleteMail(ia);
 		}
 		break;
 	case '<':
+		this->GetListCtrl().SetItemState(this->m_index, ~(LVIS_SELECTED | LVIS_FOCUSED), LVIS_SELECTED | LVIS_FOCUSED);
 		this->GetListCtrl().SetItemState(0, LVIS_SELECTED | LVIS_FOCUSED, LVIS_SELECTED | LVIS_FOCUSED);
 		this->GetListCtrl().EnsureVisible(0, TRUE);
 		break;
 	case '>':
+		this->GetListCtrl().SetItemState(this->m_index, ~(LVIS_SELECTED | LVIS_FOCUSED), LVIS_SELECTED | LVIS_FOCUSED);
 		this->GetListCtrl().SetItemState(this->m_stack_num-1, LVIS_SELECTED | LVIS_FOCUSED, LVIS_SELECTED | LVIS_FOCUSED);
 		this->GetListCtrl().EnsureVisible(this->m_stack_num-1, TRUE);
 		break;
@@ -480,6 +482,7 @@ BOOL CSummaryView::MarkDStatus(int nItem)
 void CSummaryView::SelectNext()
 {
 	if(this->m_index < m_stack_num -1){
+		this->GetListCtrl().SetItemState(this->m_index, ~(LVIS_SELECTED | LVIS_FOCUSED), LVIS_SELECTED | LVIS_FOCUSED);
 		this->GetListCtrl().SetItemState(this->m_index+1, LVIS_SELECTED | LVIS_FOCUSED, LVIS_SELECTED | LVIS_FOCUSED);
 		this->GetListCtrl().EnsureVisible(this->m_index, TRUE);
 		this->GetListCtrl().RedrawItems(this->m_index, this->m_index);
@@ -490,6 +493,7 @@ void CSummaryView::SelectNext()
 void CSummaryView::SelectPrev()
 {
 	if(this->m_index > 0){
+		this->GetListCtrl().SetItemState(this->m_index, ~(LVIS_SELECTED | LVIS_FOCUSED), LVIS_SELECTED | LVIS_FOCUSED);
 		this->GetListCtrl().SetItemState(this->m_index-1,LVIS_SELECTED | LVIS_FOCUSED, LVIS_SELECTED | LVIS_FOCUSED);
 		this->GetListCtrl().EnsureVisible(this->m_index, TRUE);
 		this->GetListCtrl().RedrawItems(this->m_index, this->m_index);
@@ -517,6 +521,7 @@ void CSummaryView::DeleteMail(CUIntArray &index_array)
 		this->m_stack_num--;
 		i--;
 	}
+
 	// something is changed.
 	this->GetListCtrl().DeleteAllItems();
 	this->m_index = -1;
