@@ -217,6 +217,7 @@ public:
 // _CAO f[^
 	//{{AFX_DATA(CAboutDlg)
 	enum { IDD = IDD_ABOUTBOX };
+	CEdit	m_edit;
 	CStatic	m_copyright;
 	CStatic	m_version;
 	//}}AFX_DATA
@@ -245,6 +246,7 @@ void CAboutDlg::DoDataExchange(CDataExchange* pDX)
 {
 	CDialog::DoDataExchange(pDX);
 	//{{AFX_DATA_MAP(CAboutDlg)
+	DDX_Control(pDX, IDC_ABOUTBOX_EDIT, m_edit);
 	DDX_Control(pDX, IDC_APPABOUT_COPY, m_copyright);
 	DDX_Control(pDX, IDC_ABOUTBOX_VERSION, m_version);
 	//}}AFX_DATA_MAP
@@ -351,6 +353,7 @@ BOOL CAboutDlg::OnInitDialog()
 	// TODO: ̈ʒuɏ̕⑫ǉĂ
 	this->m_version.SetWindowText(VERSION);
 	this->m_copyright.SetWindowText(COPYRIGHT);
+	this->m_edit.SetWindowText(CONTRIBUTORS);
 	return TRUE;  // Rg[ɃtH[JXݒ肵ȂƂA߂l TRUE ƂȂ܂
 	              // O: OCX vpeB y[W̖߂l FALSE ƂȂ܂
 }
