@@ -48,9 +48,16 @@
 #define DEF_BOXNAME_OUTBOX "Mς"
 #define DEF_BOXNAME_DRAFT "e"
 #define DEF_BOXNAME_TRASH "S~"
-#define X_MAILER "Pochy 0.1.4 (ChiangRai)"
-#define VERSION "Pochy 0.1.4 (ChiangRai)"
-#define COPYRIGHT "Copyright (C) 2003"
+#ifdef _IPV6_
+#define X_MAILER "Pochy 0.1.5 (KotaKinabalu) IPv6 ready"
+#define VERSION "Pochy 0.1.5 (KotaKinabalu) IPv6 ready"
+#else
+#define X_MAILER "Pochy 0.1.5 (KotaKinabalu)"
+#define VERSION "Pochy 0.1.5 (KotaKinabalu)"
+#endif
+#define COPYRIGHT "Copyright (C) 2003 Pochy project team"
+#define CONTRIBUTORS "\
+Portions of this software are Copyright (C) 2003 by minamina\r\n"
 #define DEF_TIME_ZONE "+0900"
 #define DEF_POP_PORT "110"
 #define DEF_SMTP_PORT "25"
